@@ -4,9 +4,9 @@
  * Gnome Chemisty Utils
  * chemistry.cc
  *
- * Copyright (C) 2003-2004
+ * Copyright (C) 2003-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -18,10 +18,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
- * USA
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the 
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA  02111-1307, USA.
  */
 
 #include "config.h"
@@ -72,4 +72,21 @@ const GcuElectronegativity** gcu_element_get_electronegativities(gint Z)
 	return Element::GetElement(Z)->GetElectronegativities();
 }
 
+void gcu_element_load_databases (char* name, ...)
+{
+	va_list l;
+	char const *base = name;
+	va_start (l, name);
+	while (base != NULL) {
+		if (!strcmp (base, "radii"))
+			Element::LoadRadii ();
+		else if (!strcmp (base, "elecprops"))
+			Element::LoadElectronicProps ();
+		else if (!strcmp (base, "isotopes"))
+			Element::LoadIsotopes ();
+		base = va_arg (l, char const*);
+	}
+	va_end (l);
+}
+
 } //extern "C"
